Module: BWAPI::Client::Author
- Included in:
- BWAPI::Client
- Defined in:
- lib/bwapi/client/author.rb
Overview
Author module for author endpoints
Instance Method Summary collapse
-
#author_interests(opts = {}) ⇒ Hash
Gets all author interests.
-
#author_professions(opts = {}) ⇒ Hash
Gets all author professions.
-
#get_author(name, opts = {}) ⇒ Hash
Get an Author with its associated accounts using an account name/domain tuple.
-
#update_author(name, opts = {}) ⇒ Hash
Update an Author using an account name/domain tuple.
Instance Method Details
#author_interests(opts = {}) ⇒ Hash
Gets all author interests
21 22 23 |
# File 'lib/bwapi/client/author.rb', line 21 def (opts = {}) get 'authors/interests', opts end |
#author_professions(opts = {}) ⇒ Hash
Gets all author professions
11 12 13 |
# File 'lib/bwapi/client/author.rb', line 11 def (opts = {}) get 'authors/professions', opts end |
#get_author(name, opts = {}) ⇒ Hash
Get an Author with its associated accounts using an account name/domain tuple
31 32 33 |
# File 'lib/bwapi/client/author.rb', line 31 def (name, opts = {}) get "authors/#{name}", opts end |
#update_author(name, opts = {}) ⇒ Hash
Update an Author using an account name/domain tuple
51 52 53 |
# File 'lib/bwapi/client/author.rb', line 51 def (name, opts = {}) patch "authors/#{name}", opts end |