Module: BWAPI::Client::Brandwatch

Includes:
Become, Clients, CommandCenter, DittoBrands, HostLocationOverrides, LogLevel, PriceStructures, UsageReport, Users
Included in:
BWAPI::Client
Defined in:
lib/bwapi/client/brandwatch.rb,
lib/bwapi/client/brandwatch/users.rb,
lib/bwapi/client/brandwatch/become.rb,
lib/bwapi/client/brandwatch/clients.rb,
lib/bwapi/client/brandwatch/log_level.rb,
lib/bwapi/client/brandwatch/ditto_brands.rb,
lib/bwapi/client/brandwatch/usage_report.rb,
lib/bwapi/client/brandwatch/clients/users.rb,
lib/bwapi/client/brandwatch/command_center.rb,
lib/bwapi/client/brandwatch/clients/modules.rb,
lib/bwapi/client/brandwatch/price_structures.rb,
lib/bwapi/client/brandwatch/command_center/themes.rb,
lib/bwapi/client/brandwatch/clients/command_center.rb,
lib/bwapi/client/brandwatch/host_location_overrides.rb,
lib/bwapi/client/brandwatch/price_structures/clients.rb,
lib/bwapi/client/brandwatch/command_center/scene_types.rb,
lib/bwapi/client/brandwatch/clients/command_center/users.rb,
lib/bwapi/client/brandwatch/clients/command_center/limits.rb,
lib/bwapi/client/brandwatch/clients/command_center/themes.rb,
lib/bwapi/client/brandwatch/clients/command_center/scene_types.rb,
lib/bwapi/client/brandwatch/clients/command_center/users/access.rb

Overview

Brandwatch module for brandwatch endpoints

Defined Under Namespace

Modules: Become, Clients, CommandCenter, DittoBrands, HostLocationOverrides, LogLevel, PriceStructures, UsageReport, Users

Instance Method Summary collapse

Methods included from Users

#brandwatch_users_details

Methods included from UsageReport

#brandwatch_usage_report

Methods included from PriceStructures

#create_price_structure, #delete_price_structure, #get_client_price_structures, #get_price_structures

Methods included from PriceStructures::Clients

#get_client_price_structures

Methods included from LogLevel

#brandwatch_log_level

Methods included from HostLocationOverrides

#get_host_location_override, #host_location_overrides

Methods included from DittoBrands

#brandwatch_ditto_brands, #create_brandwatch_ditto_brand

Methods included from CommandCenter::Themes

#brandwatch_theme_by_id, #brandwatch_theme_by_name, #brandwatch_themes, #create_brandwatch_theme, #delete_brandwatch_theme, #enabled_brandwatch_themes, #update_brandwatch_theme

Methods included from CommandCenter::SceneTypes

#brandwatch_all_scene_types, #brandwatch_scene_type, #brandwatch_scene_type_with_sub_scenes

Methods included from Clients

#brandwatch_clients, #brandwatch_create_client, #brandwatch_get_client, #brandwatch_update_client

Methods included from Clients::Modules

#brandwatch_client_modules, #update_brandwatch_client_modules

Methods included from Clients::Users

#brandwatch_create_client_user, #brandwatch_get_client_user, #brandwatch_get_client_users, #brandwatch_update_client_user

Methods included from Clients::CommandCenter::Users

#brandwatch_user_access_level, #brandwatch_users_access_levels

Methods included from Clients::CommandCenter::Users::Access

#brandwatch_delete_user_access_level, #brandwatch_update_user_access_level

Methods included from Clients::CommandCenter::Themes

#brandwatch_client_create_themes, #brandwatch_client_delete_themes, #brandwatch_client_themes

Methods included from Clients::CommandCenter::SceneTypes

#brandwatch_scene_types, #brandwatch_update_scene_type

Methods included from Clients::CommandCenter::Limits

#brandwatch_create_vizia_limits, #brandwatch_update_vizia_limits, #brandwatch_vizia_limits

Methods included from Become

#brandwatch_become

Instance Method Details

#brandwatch_data_download(project_id, opts = {}) ⇒ Hash

Create a new data download in project

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • id (Integer)

    Id of the data download

  • queryId (Integer)

    Id of the query

  • percentComplete (Int)

    The percentage complete of data download

  • status (String)

    The status of the download

  • queryName (String)

    The query name of the data download

  • endDate (Date)

    The end date of the data download

  • requestDate (Date)

    The request date of the data download

  • downloadLinkXLS (String)

    The link to download the XLS format

  • downloadLinkCSV (String)

    The link to download the CSV format

  • additionalColumns (Array)

    The additional columns for the data download

Returns:

  • (Hash)

    New data download



30
31
32
# File 'lib/bwapi/client/brandwatch.rb', line 30

def brandwatch_data_download(project_id, opts = {})
  post "brandwatch/#{project_id}/datadownload", opts
end

#delete_token_log_level(access_token) ⇒ Object

Remove the logging level override for given access token

TODO: Add parameters documentation



51
52
53
# File 'lib/bwapi/client/brandwatch.rb', line 51

def delete_token_log_level(access_token)
  delete "/brandwatch/token-log-level/#{access_token}"
end

#get_token_log_level(access_token) ⇒ Object

Get the logging level override for given access token

TODO: Add parameters documentation



44
45
46
# File 'lib/bwapi/client/brandwatch.rb', line 44

def get_token_log_level(access_token)
  get "/brandwatch/token-log-level/#{access_token}"
end

#update_token_log_level(opts = {}) ⇒ Object

Alter the logging level override for given access token

TODO: Add parameters documentation



37
38
39
# File 'lib/bwapi/client/brandwatch.rb', line 37

def update_token_log_level(opts = {})
  put '/brandwatch/token-log-level', opts
end