Module: BWAPI::Client::Brandwatch::Clients

Includes:
CommandCenter, Modules, Users
Included in:
BWAPI::Client::Brandwatch
Defined in:
lib/bwapi/client/brandwatch/clients.rb,
lib/bwapi/client/brandwatch/clients/users.rb,
lib/bwapi/client/brandwatch/clients/modules.rb,
lib/bwapi/client/brandwatch/clients/command_center.rb,
lib/bwapi/client/brandwatch/clients/command_center/users.rb,
lib/bwapi/client/brandwatch/clients/command_center/limits.rb,
lib/bwapi/client/brandwatch/clients/command_center/themes.rb,
lib/bwapi/client/brandwatch/clients/command_center/scene_types.rb,
lib/bwapi/client/brandwatch/clients/command_center/users/access.rb

Overview

Clients module for brandwatch/clients endpoints

Defined Under Namespace

Modules: CommandCenter, Modules, Users

Instance Method Summary collapse

Methods included from Modules

#brandwatch_client_modules, #update_brandwatch_client_modules

Methods included from Users

#brandwatch_create_client_user, #brandwatch_get_client_user, #brandwatch_get_client_users, #brandwatch_update_client_user

Methods included from CommandCenter::Users

#brandwatch_user_access_level, #brandwatch_users_access_levels

Methods included from CommandCenter::Users::Access

#brandwatch_delete_user_access_level, #brandwatch_update_user_access_level

Methods included from CommandCenter::Themes

#brandwatch_client_create_themes, #brandwatch_client_delete_themes, #brandwatch_client_themes

Methods included from CommandCenter::SceneTypes

#brandwatch_scene_types, #brandwatch_update_scene_type

Methods included from CommandCenter::Limits

#brandwatch_create_vizia_limits, #brandwatch_update_vizia_limits, #brandwatch_vizia_limits

Instance Method Details

#brandwatch_clients(opts = {}) ⇒ Hash

Get specific clients

Parameters:

  • opts (Hash) (defaults to: {})

    options Hash of parameters

Returns:

  • (Hash)

    List of filtered clients



15
16
17
# File 'lib/bwapi/client/brandwatch/clients.rb', line 15

def brandwatch_clients(opts = {})
  get 'brandwatch/clients', opts
end

#brandwatch_create_client(opts = {}) ⇒ Hash

Create a new parent client

Parameters:

  • opts (Hash) (defaults to: {})

    options Hash of parameters

Options Hash (opts):

  • address1 (String)

    Address line one of the client

  • address2 (String)

    Address line two of the client

  • address3 (String)

    Address line three of the client

  • contactEmail (String)

    The contact email for the client

  • contactMobile (String)

    The mobile number for the client

  • contactName (String)

    The contact name of the client

  • contactTelephone (String)

    Telephone number of the client

  • contactTitle (String)

    Contact title of the client

  • country (String)

    The country of the client

  • expiryDate (Date)

    The expiry date for the client

  • id (Integer)

    Id of the client

  • isLegacy (Boolean)

    Legacy status of the client

  • maxUsers (Integer)

    Maxiumum number of users for the client

  • maximumSubscribedBrands (Integer)

    The maximum subscribed brands for the client

  • mentionArchiveSize (Integer)

    Mention archive size for the client

  • mentionBasedPricingMatrixLevel (Integer)

    The amount of mentions allowed

  • name (String)

    Name of the client

  • owner (String)

    Owner of client

  • parentId (Integer)

    clients parent Client (subclients only)

  • postcode (String)

    The postcode of the client

  • priceStructureId (Integer)

    Id of the price structure for client

  • priceStructureLineId (Integer)

    The level of the price structure for the client

  • pricingModel (String)

    Pricing model of the client

  • startDate (Date)

    Start date of the client

  • tags (Hash)

    Tags for the client

  • theme (String)

    The theme of the client

  • website (String)

    The website for the client

Returns:

  • (Hash)

    Newly created parent client



50
51
52
# File 'lib/bwapi/client/brandwatch/clients.rb', line 50

def brandwatch_create_client(opts = {})
  post 'brandwatch/clients', opts
end

#brandwatch_get_client(client_id) ⇒ Hash

Get specific client

Parameters:

  • client_id (Integer)

    Id of the client

Returns:

  • (Hash)

    Specific client



58
59
60
# File 'lib/bwapi/client/brandwatch/clients.rb', line 58

def brandwatch_get_client(client_id)
  get "brandwatch/clients/#{client_id}"
end

#brandwatch_update_client(client_id, opts = {}) ⇒ Hash

Update an existing parent client

Parameters:

  • client_id (Integer)

    Id of the client

  • opts (Hash) (defaults to: {})

    options Hash of parameters

Options Hash (opts):

  • address1 (String)

    Address line one of the client

  • address2 (String)

    Address line two of the client

  • address3 (String)

    Address line three of the client

  • contactEmail (String)

    The contact email for the client

  • contactMobile (String)

    The mobile number for the client

  • contactName (String)

    The contact name of the client

  • contactTelephone (String)

    Telephone number of the client

  • contactTitle (String)

    Contact title of the client

  • country (String)

    The country of the client

  • expiryDate (Date)

    The expiry date for the client

  • id (Integer)

    Id of the client

  • isLegacy (Boolean)

    Legacy status of the client

  • maxUsers (Integer)

    Maxiumum number of users for the client

  • maximumSubscribedBrands (Integer)

    The maximum subscribed brands for the client

  • mentionArchiveSize (Integer)

    Mention archive size for the client

  • mentionBasedPricingMatrixLevel (Integer)

    The amount of mentions allowed

  • name (String)

    Name of the client

  • owner (String)

    Owner of client

  • parentId (Integer)

    clients parent Client (subclients only)

  • postcode (String)

    The postcode of the client

  • priceStructureId (Integer)

    Id of the price structure for client

  • priceStructureLineId (Integer)

    The level of the price structure for the client

  • pricingModel (String)

    Pricing model of the client

  • startDate (Date)

    Start date of the client

  • tags (Hash)

    Tags for the client

  • theme (String)

    The theme of the client

  • website (String)

    The website for the client

Returns:

  • (Hash)

    Updated parent client



94
95
96
# File 'lib/bwapi/client/brandwatch/clients.rb', line 94

def brandwatch_update_client(client_id, opts = {})
  put "brandwatch/clients/#{client_id}", opts
end