Module: BWAPI::Client::Projects::BulkActions::Author
- Included in:
- BWAPI::Client::Projects::BulkActions
- Defined in:
- lib/bwapi/client/projects/bulk_actions/author.rb
Overview
Author module for projects/bulkactions/author endpoints
Instance Method Summary collapse
-
#bulk_edit_author(project_id, opts = {}) ⇒ Hash
Create a new bulk action in project for an author.
Instance Method Details
#bulk_edit_author(project_id, opts = {}) ⇒ Hash
Create a new bulk action in project for an author
19 20 21 |
# File 'lib/bwapi/client/projects/bulk_actions/author.rb', line 19 def (project_id, opts = {}) post "projects/#{project_id}/bulkactions/author", opts end |