Module: BWAPI::Client::Projects::BulkActions::Mentions

Included in:
BWAPI::Client::Projects::BulkActions
Defined in:
lib/bwapi/client/projects/bulkactions/mentions.rb

Overview

Mentions module for projects/bulkactions/mentions endpoints

Instance Method Summary collapse

Instance Method Details

#bulk_edit_mentions(project_id, opts = {}) ⇒ Hashie::Mash

Create a new bulk action in project for mentions

Options Hash (opts):

  • action (Hash)

    to apply to these mentions

  • filter (Hash)

    to specify what kind of mentions this bulk action should apply to

  • sampleAmount (Integer)

    Amount to be sample by this bulk action



17
18
19
# File 'lib/bwapi/client/projects/bulkactions/mentions.rb', line 17

def bulk_edit_mentions(project_id, opts = {})
  post "projects/#{project_id}/bulkactions/mentions", opts
end