Module: BWAPI::Client::Projects::Data
- Included in:
- BWAPI::Client::Projects
- Defined in:
- lib/bwapi/client/projects/data.rb
Overview
Data module for projects/data endpoints
Instance Method Summary collapse
-
#data(project_id, aggregate, dimension_one, dimension_two, opts = {}) ⇒ Hashie::Mash
Get all chart data for the requested dimensions.
-
#data_date_ranges_days(project_id, opts) ⇒ Hashie::Mash
Get all chart data for date ranges broken down by days.
-
#data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters.
-
#update_data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Update mentions for project.
Instance Method Details
#data(project_id, aggregate, dimension_one, dimension_two, opts = {}) ⇒ Hashie::Mash
Get all chart data for the requested dimensions
17 18 19 |
# File 'lib/bwapi/client/projects/data.rb', line 17 def data project_id, aggregate, dimension_one, dimension_two, opts={} get "projects/#{project_id}/data/#{aggregate}/#{dimension_one}/#{dimension_two}", opts end |
#data_date_ranges_days(project_id, opts) ⇒ Hashie::Mash
Get all chart data for date ranges broken down by days
28 29 30 |
# File 'lib/bwapi/client/projects/data.rb', line 28 def data_date_ranges_days project_id, opts get "projects/#{project_id}/data/volume/dataRanges/days", opts end |
#data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters
43 44 45 |
# File 'lib/bwapi/client/projects/data.rb', line 43 def data_mentions project_id, opts={} get "projects/#{project_id}/data/mentions", opts end |
#update_data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Update mentions for project
53 54 55 |
# File 'lib/bwapi/client/projects/data.rb', line 53 def update_data_mentions project_id, opts={} patch "projects/#{project_id}/data/mentions", opts end |