Module: BWAPI::Client::Projects::Data::Mentions

Includes:
Notes
Included in:
BWAPI::Client::Projects::Data
Defined in:
lib/bwapi/client/projects/data/mentions.rb,
lib/bwapi/client/projects/data/mentions/notes.rb

Overview

Mentions module for projects/data/mentions endpoints

Defined Under Namespace

Modules: Notes

Instance Method Summary collapse

Methods included from Notes

#create_mention_note, #mention_note, #patch_mention_note, #update_mention_note

Instance Method Details

#data_mentions(project_id, opts = {}) ⇒ Hash

Get mentions that fall within the submitted filters

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hash)

    All Mentions



20
21
22
# File 'lib/bwapi/client/projects/data/mentions.rb', line 20

def data_mentions(project_id, opts = {})
  get "projects/#{project_id}/data/mentions", opts
end

#data_mentions_count(project_id, opts = {}) ⇒ Object

Retrieve the total count of mentions for the requested queries

TODO: Add parameters documentation



27
28
29
# File 'lib/bwapi/client/projects/data/mentions.rb', line 27

def data_mentions_count(project_id, opts = {})
  get "/projects/#{project_id}/data/mentions/count", opts
end

#data_mentions_facebook_comments(project_id, opts = {}) ⇒ Hash

Get mentions that fall within the submitted filters for all facebook comments

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hash)

    All Mentions



97
98
99
# File 'lib/bwapi/client/projects/data/mentions.rb', line 97

def data_mentions_facebook_comments(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/facebookcomments", opts
end

#data_mentions_facebook_posts(project_id, opts = {}) ⇒ Hash

Get mentions that fall within the submitted filters for all facebook posts

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hash)

    All Mentions



82
83
84
# File 'lib/bwapi/client/projects/data/mentions.rb', line 82

def data_mentions_facebook_posts(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/facebookposts", opts
end

#data_mentions_full_text(project_id, opts = {}) ⇒ Hash

Get mentions that fall within the submitted filters with full text

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hash)

    All Mentions



52
53
54
# File 'lib/bwapi/client/projects/data/mentions.rb', line 52

def data_mentions_full_text(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/fulltext", opts
end

#data_mentions_tweets(project_id, opts = {}) ⇒ Hash

Get mentions that fall within the submitted filters with fulltext

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hash)

    All Mentions



67
68
69
# File 'lib/bwapi/client/projects/data/mentions.rb', line 67

def data_mentions_tweets(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/tweets", opts
end

#update_data_mentions(project_id, opts = {}) ⇒ Hash

Update mentions for project

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • List (Hash)

    The patches to be applied

Returns:

  • (Hash)

    Updated mentions



37
38
39
# File 'lib/bwapi/client/projects/data/mentions.rb', line 37

def update_data_mentions(project_id, opts = {})
  patch "projects/#{project_id}/data/mentions", opts
end