Module: BWAPI::Client::Projects::Research
- Included in:
- BWAPI::Client::Projects
- Defined in:
- lib/bwapi/client/projects/research.rb
Overview
Research module for research projects endpoints
Instance Method Summary collapse
-
#get_research_projects(opts = {}) ⇒ Hash
Get all research projects.
-
#update_research_projects(project_id, opts = {}) ⇒ Hash
Edits a published project and returns the published attributes.
Instance Method Details
#get_research_projects(opts = {}) ⇒ Hash
Get all research projects
12 13 14 |
# File 'lib/bwapi/client/projects/research.rb', line 12 def get_research_projects(opts = {}) get 'projects/published', opts end |
#update_research_projects(project_id, opts = {}) ⇒ Hash
Edits a published project and returns the published attributes
23 24 25 |
# File 'lib/bwapi/client/projects/research.rb', line 23 def update_research_projects(project_id, opts = {}) put "projects/published/#{project_id}", opts end |