Module: BWAPI::Client::Projects::Data::Mentions

Included in:
BWAPI::Client::Projects::Data
Defined in:
lib/bwapi/client/projects/data/mentions.rb

Overview

Mentions module for projects/data/mentions endpoints

Instance Method Summary collapse

Instance Method Details

#data_mentions(project_id, opts = {}) ⇒ Hashie::Mash

Get mentions that fall within the submitted filters

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hashie::Mash)

    All Mentions



20
21
22
# File 'lib/bwapi/client/projects/data/mentions.rb', line 20

def data_mentions(project_id, opts = {})
  get "projects/#{project_id}/data/mentions", opts
end

#data_mentions_fulltext(project_id, opts = {}) ⇒ Hashie::Mash

Get mentions that fall within the submitted filters with fulltext

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hashie::Mash)

    All Mentions



45
46
47
# File 'lib/bwapi/client/projects/data/mentions.rb', line 45

def data_mentions_fulltext(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/fulltext", opts
end

#data_mentions_tweets(project_id, opts = {}) ⇒ Hashie::Mash

Get mentions that fall within the submitted filters with fulltext

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • filter (Hash)

    The filters to apply

  • page (Integer)

    Page of projects to retrieve

  • pageSize (Integer)

    Results per page of results

  • orderBy (String)

    Parameter to sort by

  • orderDirection (String)

    Direction of sort

  • orderByCategory (Integer)

    Category to sort by when orderBy category

Returns:

  • (Hashie::Mash)

    All Mentions



60
61
62
# File 'lib/bwapi/client/projects/data/mentions.rb', line 60

def data_mentions_tweets(project_id, opts = {})
  get "projects/#{project_id}/data/mentions/tweets", opts
end

#update_data_mentions(project_id, opts = {}) ⇒ Hashie::Mash

Update mentions for project

Parameters:

  • project_id (Integer)

    Id of project

  • opts (Hash) (defaults to: {})

    options hash of parameters

Options Hash (opts):

  • List (Hash)

    The patches to be applied

Returns:

  • (Hashie::Mash)

    Updated mentions



30
31
32
# File 'lib/bwapi/client/projects/data/mentions.rb', line 30

def update_data_mentions(project_id, opts = {})
  patch "projects/#{project_id}/data/mentions", opts
end