Module: BWAPI::Client::Projects::Data::Mentions
- Included in:
- BWAPI::Client::Projects::Data
- Defined in:
- lib/bwapi/client/projects/data/mentions.rb
Overview
Mentions module for projects/data/mentions endpoints
Instance Method Summary collapse
-
#data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters.
-
#data_mentions_fulltext(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters with fulltext.
-
#data_mentions_tweets(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters with fulltext.
-
#update_data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Update mentions for project.
Instance Method Details
#data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters
19 20 21 |
# File 'lib/bwapi/client/projects/data/mentions.rb', line 19 def data_mentions project_id, opts={} get "projects/#{project_id}/data/mentions", opts end |
#data_mentions_fulltext(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters with fulltext
44 45 46 |
# File 'lib/bwapi/client/projects/data/mentions.rb', line 44 def data_mentions_fulltext project_id, opts={} get "projects/#{project_id}/data/mentions/fulltext", opts end |
#data_mentions_tweets(project_id, opts = {}) ⇒ Hashie::Mash
Get mentions that fall within the submitted filters with fulltext
59 60 61 |
# File 'lib/bwapi/client/projects/data/mentions.rb', line 59 def data_mentions_tweets project_id, opts={} get "projects/#{project_id}/data/mentions/tweets", opts end |
#update_data_mentions(project_id, opts = {}) ⇒ Hashie::Mash
Update mentions for project
29 30 31 |
# File 'lib/bwapi/client/projects/data/mentions.rb', line 29 def update_data_mentions project_id, opts={} patch "projects/#{project_id}/data/mentions", opts end |